@@ -386,11 +386,22 @@ __print_funct_t print_io_stats(struct activity *a, int prev, int curr,
 	}
 
 	printf("%-11s", timestamp[curr]);
+	/*
+	 * If we get negative values, this is probably because
+	 * one or more devices/filesystems have been unmounted.
+	 * We display 0.0 in this case though we should rather tell
+	 * the user that the value cannot be calculated here.
+	 */
 	cprintf_f(5, 9, 2,
-		  S_VALUE(sip->dk_drive,      sic->dk_drive,      itv),
-		  S_VALUE(sip->dk_drive_rio,  sic->dk_drive_rio,  itv),
-		  S_VALUE(sip->dk_drive_wio,  sic->dk_drive_wio,  itv),
+		  sic->dk_drive < sip->dk_drive ? 0.0 :
+		  S_VALUE(sip->dk_drive, sic->dk_drive, itv),
+		  sic->dk_drive_rio < sip->dk_drive_rio ? 0.0 :
+		  S_VALUE(sip->dk_drive_rio, sic->dk_drive_rio, itv),
+		  sic->dk_drive_wio < sip->dk_drive_wio ? 0.0 :
+		  S_VALUE(sip->dk_drive_wio, sic->dk_drive_wio, itv),
+		  sic->dk_drive_rblk < sip->dk_drive_rblk ? 0.0 :
 		  S_VALUE(sip->dk_drive_rblk, sic->dk_drive_rblk, itv),
+		  sic->dk_drive_wblk < sip->dk_drive_wblk ? 0.0 :
 		  S_VALUE(sip->dk_drive_wblk, sic->dk_drive_wblk, itv));
 	printf("\n");
 }
